# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.1] - 2026-03-30
### Updated
- OctoBot to 2.1.1
- Added python 3.13 support

## [0.1.0] - 2026-02-27
### Added
- Support for services tentacles
- Support for profile scripting
### Updated
- Report redesign

## [0.0.29] - 2025-12-29
### Updated
- OctoBot to 2.0.16

## [0.0.28] - 2025-12-10
### Updated
- OctoBot to 2.0.15

## [0.0.27] - 2025-10-18
### Updated
- OctoBot to 2.0.13

## [0.0.26] - 2025-06-09
### Updated
- OctoBot to 2.0.12

## [0.0.25] - 2025-06-06
### Updated
- OctoBot to 2.0.11

## [0.0.24] - 2025-05-25
### Updated
- OctoBot to 2.0.10

## [0.0.23] - 2025-03-10
### Updated
- OctoBot to 2.0.9

## [0.0.22] - 2025-01-29
### Updated
- OctoBot to 2.0.8

## [0.0.21] - 2024-10-28
### Updated
- OctoBot to 2.0.7
### Fixed
- Indicators plotting

## [0.0.20] - 2024-10-11
### Updated
- OctoBot to 2.0.6

## [0.0.19] - 2024-10-01
### Updated
- OctoBot to 2.0.5

## [0.0.18] - 2024-07-10
### Updated
- OctoBot to 2.0.1

## [0.0.17] - 2024-05-01
### Updated
- OctoBot to 1.0.10

## [0.0.16] - 2023-01-14
### Updated
- OctoBot to 1.0.6

## [0.0.15] - 2023-12-15
### Updated
- OctoBot to 1.0.4

## [0.0.14] - 2023-10-30
### Updated
- OctoBot to 1.0.2

## [0.0.13] - 2023-10-09
### Updated
- Renamed from OctoBot Pro to OctoBot Script

## [0.0.12] - 2023-09-27
### Added
- Dockerfile
- Docker image on dockerhub
### Update
- Update to OctoBot 1.0.0

## [0.0.11] - 2023-09-23
### Update
- Update to OctoBot 0.4.54

## [0.0.10] - 2022-05-13
### Update
- Added python 3.9 and 3.10 support
- Update to OctoBot 0.4.50

## [0.0.9] - 2022-05-02
### Update
- Update to OctoBot 0.4.49

## [0.0.8] - 2022-03-24
### Update
- Update to OctoBot 0.4.45

## [0.0.7] - 2022-03-07
### Update
- Update to OctoBot 0.4.41

## [0.0.6] - 2022-01-21
### Fix
- Typeerror and report issues

## [0.0.5] - 2022-01-14
### Fix
- Installation: remove cryptofeed requirement in OctoBot

## [0.0.4] - 2022-30-12
### Added
- Report generation time

## [0.0.3] - 2022-29-12
### Fixed
- Install

## [0.0.2] - 2022-29-12
### Updated
- Install method

## [0.0.1] - 2022-10-12
### Added
- OctoBot Pro alpha version
